#!/bin/ksh
##
## install.sh -- script to install SysMon monitor and related scripts
##
## $Id: install.sh,v 1.2 1998/08/15 20:06:26 bess Exp $

PATH=/bin:/usr/bin:/sbin

if [ ${DEBUG} ]; then
	set -x
fi

#
# Are we root?
#
UID=`id | cut -d'(' -f1 | cut -d'=' -f2`
if [ $UID -ne 0 ]; then
	echo "You must be root to run $0."
	exit 1
fi

################################################
#
# Start of file check
#
for file in install.sh sysmon.tar
do
	if [ ! -f $file ]; then
		echo "install.sh and sysmon.tar must be in `pwd`"
		exit 1
	fi
done
#
# End of file check
#
################################################

################################################
#
# Start of define INSTALLDIR
#
clear
echo "-- SysMon installation script"
echo
echo "Install path for SysMon framework (/usr/local/sysmon): \c"
read INSTALLDIR

if [ -z "${INSTALLDIR}" ]; then
	INSTALLDIR=/usr/local/sysmon
fi

if [ ! -d $INSTALLDIR ]; then
	mkdir $INSTALLDIR > /dev/null

	if [ $? = 1 ]; then
		echo "Root does not have write permission to $INSTALLDIR."
		echo "Please change the permissions on $INSTALLDIR or rerun"
		echo "the install.sh script and select a different area."
		exit 1
	fi

	chmod 2775 $INSTALLDIR
	cd $INSTALLDIR
	echo "Untarring files..."
	tar xf /tmp/sysmon.tar

fi	
#
# End of define INSTALLDIR
#
################################################

################################################
#
# Start of hosts to install
#
echo
echo "Input host names where sysmon.sh is to run. Terminate with blank line"
echo "I will check each host to make sure `hostname` is trusted to it."
echo

while [ 1 ];
do
	echo "hostname: \c"
	read HOST

	if [ -z "${HOST}" ]; then
		break
	else
		rsh ${HOST} pwd > /dev/null
		if [ $? = 0 ]; then
			echo "Installing.."
			cd $INSTALLDIR
			rcp -p bin/sysmon $HOST:/etc/init.d
			rsh $HOST "ln /etc/init.d/sysmon /etc/rc2.d/S99sysmon"
		else
			echo "$HOST does not trust `hostname`."
		fi
	fi
done
#
# End of hosts to install
#
################################################

################################################
#
# Start of Web server file installs
#
echo
echo "Name of webserver : \c"
read WEB

rsh ${WEB} pwd > /dev/null
if [ $? = 1 ]; then
	echo "$WEB does not trust `hostname`."
	echo "You must install the cgi and html docs by hand.."
else
	echo "cgi-bin directory path on $WEB : \c"
	read CGI

	echo "html document directory on $WEB : \c"
	read HTML

	cd $INSTALLDIR/cgi
	for file in `ls -1`
	do
		rcp -p $file $WEB:$CGI
	done

	cd $INSTALLDIR/html
	for file in `ls -1`
	do
		rcp -p $file $WEB:$HTML
	done

fi
#
# End of Web server file installs
#
##################################################

##################################################
#
# Start of crontab modifications
#

echo 
echo "Do you wish to add print monitors to root's cron? : \c"
read PRTMON

if [ $PRTMON = "y" ]; then
	echo "Modifying crontab..."
	cd /var/spool/cron/crontabs
	cp root ../root.`date +%y%m%d_%H:%M`.printer
	echo "00,10,20,30,40,50 * * * * /usr/local/sysmon/bin/prtmon.sh > /dev/null 2>&1 " >> root
	echo "root crontab moved to ../root.`date +%y%m%d_%H:%M`"
	echo "Restarting cron.."
	etc/init.d/cron stop
	sleep 2
	/etc/init.d/cron start
fi

echo 
echo "Do you wish to add the NetApp monitors to root's cron? : \c"
read NETAPP

if [ $NETAPP = "y" ]; then
	echo "Modifying crontab..."
	cd /var/spool/cron/crontabs
	cp root ../root.`date +%y%m%d_%H:%M`.netapp
	echo "00,15,30,45 * * * * /usr/local/sysmon/bin/namon.sh > /dev/null 2>&1" >> root
	echo "root crontab moved to ../root.`date +%y%m%d_%H:%M`.netapp"
	echo "Restarting cron.."
	/etc/init.d/cron stop
	sleep 2
	/etc/init.d/cron start
fi

echo 
echo "Do you wish to add the inventory html script to root's cron? : \c"
read INVCRON

if [ $INVCRON = "y" ]; then
	echo "Modifying crontab..."
	cd /var/spool/cron/crontabs
	cp root ../root.`date +%y%m%d_%H:%M`.inventory
	echo "01 02 * * * /usr/local/sysmon/bin/invhtml.sh >/dev/null 2>&1" >> root
	echo "root crontab moved to ../root.`date +%y%m%d_%H:%M`.inventory"
	echo "Restarting cron.."
	/etc/init.d/cron stop
	sleep 2
	/etc/init.d/cron start
fi	

echo 
echo "Do you wish to add the disk monitor script to root's cron? : \c"
read DISKMON

if [ $DISKMON = "y" ]; then
	echo "Modifying crontab..."
	cd /var/spool/cron/crontabs
	cp root ../root.`date +%y%m%d_%H:%M`.diskmon
	echo "00 08,12,15 * * * /fnc/adm/tools/diskdaily.sh > /dev/null 2>&1" >> root
	echo "root crontab moved to ../root.`date +%y%m%d_%H:%M`.diskmon"
	echo "Restarting cron.."
	/etc/init.d/cron stop
	sleep 2
	/etc/init.d/cron start
fi	

echo
echo "Installation of SysMon finished."
